==> 1.5.2.tar.xz: 1.5.2/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"首页",url:"index.html"},
{text:"相关页面",url:"pages.html"},
{text:"专题",url:"topics.html"},
{text:"命名空间",url:"namespaces.html",children:[
{text:"命名空间列表",url:"namespaces.html"},
{text:"命名空间成员",url:"namespacemembers.html",children:[
{text:"全部",url:"namespacemembers.html",children:[
{text:"a",url:"namespacemembers.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"x",url:"namespacemembers_x.html#index_x"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"函数",url:"namespacemembers_func.html",children:[
{text:"b",url:"namespacemembers_func.html#index_b"},
{text:"c",url:"namespacemembers_func.html#index_c"},
{text:"d",url:"namespacemembers_func.html#index_d"},
{text:"e",url:"namespacemembers_func.html#index_e"},
{text:"f",url:"namespacemembers_func.html#index_f"},
{text:"g",url:"namespacemembers_func.html#index_g"},
{text:"l",url:"namespacemembers_func.html#index_l"},
{text:"m",url:"namespacemembers_func.html#index_m"},
{text:"n",url:"namespacemembers_func.html#index_n"},
{text:"o",url:"namespacemembers_func.html#index_o"},
{text:"p",url:"namespacemembers_func.html#index_p"},
{text:"r",url:"namespacemembers_func.html#index_r"},
{text:"s",url:"namespacemembers_func.html#index_s"},
{text:"t",url:"namespacemembers_func.html#index_t"},
{text:"w",url:"namespacemembers_func.html#index_w"},
{text:"z",url:"namespacemembers_func.html#index_z"}]},
{text:"变量",url:"namespacemembers_vars.html",children:[
{text:"a",url:"namespacemembers_vars.html#index_a"},
{text:"c",url:"namespacemembers_vars.html#index_c"},
{text:"e",url:"namespacemembers_vars.html#index_e"},
{text:"g",url:"namespacemembers_vars.html#index_g"},
{text:"h",url:"namespacemembers_vars.html#index_h"},
{text:"l",url:"namespacemembers_vars.html#index_l"},
{text:"m",url:"namespacemembers_vars.html#index_m"},
{text:"o",url:"namespacemembers_vars.html#index_o"},
{text:"p",url:"namespacemembers_vars.html#index_p"},
{text:"r",url:"namespacemembers_vars.html#index_r"},
{text:"s",url:"namespacemembers_vars.html#index_s"},
{text:"t",url:"namespacemembers_vars.html#index_t"}]},
{text:"类型定义",url:"namespacemembers_type.html",children:[
{text:"d",url:"namespacemembers_type.html#index_d"},
{text:"e",url:"namespacemembers_type.html#index_e"},
{text:"f",url:"namespacemembers_type.html#index_f"},
{text:"k",url:"namespacemembers_type.html#index_k"},
{text:"m",url:"namespacemembers_type.html#index_m"},
{text:"o",url:"namespacemembers_type.html#index_o"},
{text:"s",url:"namespacemembers_type.html#index_s"},
{text:"v",url:"namespacemembers_type.html#index_v"}]},
{text:"枚举",url:"namespacemembers_enum.html"},
{text:"枚举值",url:"namespacemembers_eval.html",children:[
{text:"a",url:"namespacemembers_eval.html#index_a"},
{text:"b",url:"namespacemembers_eval.html#index_b"},
{text:"c",url:"namespacemembers_eval.html#index_c"},
{text:"d",url:"namespacemembers_eval.html#index_d"},
{text:"g",url:"namespacemembers_eval.html#index_g"},
{text:"p",url:"namespacemembers_eval.html#index_p"},
{text:"r",url:"namespacemembers_eval.html#index_r"},
{text:"v",url:"namespacemembers_eval.html#index_v"},
{text:"x",url:"namespacemembers_eval.html#index_x"},
{text:"y",url:"namespacemembers_eval.html#index_y"},
{text:"z",url:"namespacemembers_eval.html#index_z"}]}]}]},
{text:"类",url:"annotated.html",children:[
{text:"类列表",url:"annotated.html"},
{text:"类索引",url:"classes.html"},
{text:"类继承关系",url:"inherits.html"},
{text:"类成员",url:"functions.html",children:[
{text:"全部",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"函数",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"变量",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"类型定义",url:"functions_type.html",children:[
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"h",url:"functions_type.html#index_h"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"v",url:"functions_type.html#index_v"}]},
{text:"枚举",url:"functions_enum.html"},
{text:"枚举值",url:"functions_eval.html"}]}]},
{text:"文件",url:"files.html",children:[
{text:"文件列表",url:"files.html"},
{text:"文件成员",url:"globals.html",children:[
{text:"全部",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals.html#index_a"},
{text:"d",url:"globals.html#index_d"},
{text:"e",url:"globals.html#index_e"},
{text:"h",url:"globals.html#index_h"},
{text:"i",url:"globals.html#index_i"},
{text:"o",url:"globals.html#index_o"},
{text:"p",url:"globals.html#index_p"},
{text:"r",url:"globals.html#index_r"},
{text:"u",url:"globals.html#index_u"},
{text:"w",url:"globals.html#index_w"}]},
{text:"类型定义",url:"globals_type.html"},
{text:"枚举",url:"globals_enum.html"},
{text:"枚举值",url:"globals_eval.html"},
{text:"宏定义",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"d",url:"globals_defs.html#index_d"},
{text:"e",url:"globals_defs.html#index_e"},
{text:"h",url:"globals_defs.html#index_h"},
{text:"i",url:"globals_defs.html#index_i"},
{text:"o",url:"globals_defs.html#index_o"},
{text:"p",url:"globals_defs.html#index_p"},
{text:"r",url:"globals_defs.html#index_r"},
{text:"u",url:"globals_defs.html#index_u"},
{text:"w",url:"globals_defs.html#index_w"}]}]}]},
{text:"示例",url:"examples.html"}]}

==> 2.3.0.tar.xz: 2.3.0/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"首页",url:"index.html"},
{text:"相关页面",url:"pages.html"},
{text:"专题",url:"topics.html"},
{text:"命名空间",url:"namespaces.html",children:[
{text:"命名空间列表",url:"namespaces.html"},
{text:"命名空间成员",url:"namespacemembers.html",children:[
{text:"全部",url:"namespacemembers.html",children:[
{text:"a",url:"namespacemembers.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"i",url:"namespacemembers_i.html#index_i"},
{text:"j",url:"namespacemembers_j.html#index_j"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"u",url:"namespacemembers_u.html#index_u"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"函数",url:"namespacemembers_func.html",children:[
{text:"b",url:"namespacemembers_func.html#index_b"},
{text:"c",url:"namespacemembers_func.html#index_c"},
{text:"d",url:"namespacemembers_func.html#index_d"},
{text:"e",url:"namespacemembers_func.html#index_e"},
{text:"f",url:"namespacemembers_func.html#index_f"},
{text:"g",url:"namespacemembers_func.html#index_g"},
{text:"i",url:"namespacemembers_func.html#index_i"},
{text:"j",url:"namespacemembers_func.html#index_j"},
{text:"l",url:"namespacemembers_func.html#index_l"},
{text:"m",url:"namespacemembers_func.html#index_m"},
{text:"o",url:"namespacemembers_func.html#index_o"},
{text:"p",url:"namespacemembers_func.html#index_p"},
{text:"r",url:"namespacemembers_func.html#index_r"},
{text:"s",url:"namespacemembers_func.html#index_s"},
{text:"t",url:"namespacemembers_func.html#index_t"},
{text:"u",url:"namespacemembers_func.html#index_u"},
{text:"v",url:"namespacemembers_func.html#index_v"},
{text:"w",url:"namespacemembers_func.html#index_w"},
{text:"z",url:"namespacemembers_func.html#index_z"}]},
{text:"变量",url:"namespacemembers_vars.html",children:[
{text:"a",url:"namespacemembers_vars.html#index_a"},
{text:"c",url:"namespacemembers_vars.html#index_c"},
{text:"e",url:"namespacemembers_vars.html#index_e"},
{text:"f",url:"namespacemembers_vars.html#index_f"},
{text:"g",url:"namespacemembers_vars.html#index_g"},
{text:"h",url:"namespacemembers_vars.html#index_h"},
{text:"i",url:"namespacemembers_vars.html#index_i"},
{text:"l",url:"namespacemembers_vars.html#index_l"},
{text:"m",url:"namespacemembers_vars.html#index_m"},
{text:"n",url:"namespacemembers_vars.html#index_n"},
{text:"o",url:"namespacemembers_vars.html#index_o"},
{text:"p",url:"namespacemembers_vars.html#index_p"},
{text:"r",url:"namespacemembers_vars.html#index_r"},
{text:"s",url:"namespacemembers_vars.html#index_s"},
{text:"t",url:"namespacemembers_vars.html#index_t"}]},
{text:"类型定义",url:"namespacemembers_type.html",children:[
{text:"c",url:"namespacemembers_type.html#index_c"},
{text:"d",url:"namespacemembers_type.html#index_d"},
{text:"e",url:"namespacemembers_type.html#index_e"},
{text:"f",url:"namespacemembers_type.html#index_f"},
{text:"i",url:"namespacemembers_type.html#index_i"},
{text:"k",url:"namespacemembers_type.html#index_k"},
{text:"m",url:"namespacemembers_type.html#index_m"},
{text:"o",url:"namespacemembers_type.html#index_o"},
{text:"r",url:"namespacemembers_type.html#index_r"},
{text:"s",url:"namespacemembers_type.html#index_s"},
{text:"v",url:"namespacemembers_type.html#index_v"}]},
{text:"枚举",url:"namespacemembers_enum.html"},
{text:"枚举值",url:"namespacemembers_eval.html",children:[
{text:"a",url:"namespacemembers_eval.html#index_a"},
{text:"b",url:"namespacemembers_eval.html#index_b"},
{text:"c",url:"namespacemembers_eval.html#index_c"},
{text:"d",url:"namespacemembers_eval.html#index_d"},
{text:"g",url:"namespacemembers_eval.html#index_g"},
{text:"p",url:"namespacemembers_eval.html#index_p"},
{text:"r",url:"namespacemembers_eval.html#index_r"},
{text:"v",url:"namespacemembers_eval.html#index_v"},
{text:"y",url:"namespacemembers_eval.html#index_y"}]}]}]},
{text:"概念",url:"concepts.html"},
{text:"类",url:"annotated.html",children:[
{text:"类列表",url:"annotated.html"},
{text:"类索引",url:"classes.html"},
{text:"类继承关系",url:"inherits.html"},
{text:"类成员",url:"functions.html",children:[
{text:"全部",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"函数",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"变量",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"类型定义",url:"functions_type.html",children:[
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"h",url:"functions_type.html#index_h"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"v",url:"functions_type.html#index_v"}]},
{text:"相关符号",url:"functions_rela.html"}]}]},
{text:"文件",url:"files.html",children:[
{text:"文件列表",url:"files.html"},
{text:"文件成员",url:"globals.html",children:[
{text:"全部",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals.html#index_a"},
{text:"d",url:"globals.html#index_d"},
{text:"e",url:"globals.html#index_e"},
{text:"h",url:"globals.html#index_h"},
{text:"i",url:"globals.html#index_i"},
{text:"o",url:"globals.html#index_o"},
{text:"p",url:"globals.html#index_p"},
{text:"r",url:"globals.html#index_r"},
{text:"u",url:"globals.html#index_u"},
{text:"w",url:"globals.html#index_w"}]},
{text:"类型定义",url:"globals_type.html"},
{text:"枚举",url:"globals_enum.html"},
{text:"枚举值",url:"globals_eval.html"},
{text:"宏定义",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"d",url:"globals_defs.html#index_d"},
{text:"e",url:"globals_defs.html#index_e"},
{text:"h",url:"globals_defs.html#index_h"},
{text:"i",url:"globals_defs.html#index_i"},
{text:"o",url:"globals_defs.html#index_o"},
{text:"p",url:"globals_defs.html#index_p"},
{text:"r",url:"globals_defs.html#index_r"},
{text:"u",url:"globals_defs.html#index_u"},
{text:"w",url:"globals_defs.html#index_w"}]}]}]},
{text:"示例",url:"examples.html"}]}
